@@ -20,7 +20,9 @@ import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-rds", "1.47.0", __name__[0:-6], "aws-rds@1.47.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-rds", "1.57.0", __name__[0:-6], "aws-rds@1.57.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
